==> jc-1.4.0.tar.gz: java/rmi/registry/LocateRegistry.h <==
// public final class java.rmi.registry.LocateRegistry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 93cb7af69e6ba275 java_rmi_registry_LocateRegistry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_registry_LocateRegistry_H_
#define _JC_java_rmi_registry_LocateRegistry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_registry_Registry$object;
struct _jc_java_rmi_server_RMIClientSocketFactory$object;
struct _jc_java_rmi_server_RMIServerSocketFactory$object;

// Typedefs
typedef struct _jc_java_rmi_registry_LocateRegistry$sub_refs	_jc_java_rmi_registry_LocateRegistry$sub_refs;
typedef struct _jc_java_rmi_registry_LocateRegistry$sub_nonrefs	_jc_java_rmi_registry_LocateRegistry$sub_nonrefs;
typedef struct _jc_java_rmi_registry_LocateRegistry$refs	_jc_java_rmi_registry_LocateRegistry$refs;
typedef struct _jc_java_rmi_registry_LocateRegistry$nonrefs	_jc_java_rmi_registry_LocateRegistry$nonrefs;
typedef struct _jc_java_rmi_registry_LocateRegistry$object	_jc_java_rmi_registry_LocateRegistry$object;

typedef const struct _jc_java_rmi_registry_LocateRegistry$vmethods	_jc_java_rmi_registry_LocateRegistry$vmethods;
typedef const struct _jc_java_rmi_registry_LocateRegistry$vtable	_jc_java_rmi_registry_LocateRegistry$vtable;
typedef const struct _jc_java_rmi_registry_LocateRegistry$vtype	_jc_java_rmi_registry_LocateRegistry$vtype;

// Constructors
extern void _jc_java_rmi_registry_LocateRegistry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_registry_LocateRegistry$object *);

// Static methods
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$createRegistry$3504ad846b08bdcc(_jc_env *, jint);
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$createRegistry$bde0ac03af6cf041(_jc_env *, jint, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$4a5a02146fc309d6(_jc_env *);
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$bc7b68f475c68629(_jc_env *, jint);
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$a7faf9586294501a(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$5c01493dac7358a7(_jc_env *, struct _jc_java_lang_String$object *, jint);
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$99a1e5a9f3dd3803(_jc_env *, struct _jc_java_lang_String$object *, jint, struct _jc_object *);

// Virtual methods structure
struct _jc_java_rmi_registry_LocateRegistry$vmethods {
};

// Vtable
struct _jc_java_rmi_registry_LocateRegistry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_registry_LocateRegistry$vmethods	java_rmi_registry_LocateRegistry;
};

// Vtype
struct _jc_java_rmi_registry_LocateRegistry$vtype {
	_jc_type			type;
	_jc_java_rmi_registry_LocateRegistry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_registry_LocateRegistry$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_registry_LocateRegistry$refs {
    _jc_java_rmi_registry_LocateRegistry$sub_refs	java_rmi_registry_LocateRegistry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_registry_LocateRegistry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_registry_LocateRegistry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_registry_LocateRegistry$sub_nonrefs	java_rmi_registry_LocateRegistry;
};

// Object instance structure
struct _jc_java_rmi_registry_LocateRegistry$object {
	_jc_java_rmi_registry_LocateRegistry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_registry_LocateRegistry$vtype	*vtype;
	_jc_java_rmi_registry_LocateRegistry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_registry_LocateRegistry$vtype _jc_java_rmi_registry_LocateRegistry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_registry_LocateRegistry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_registry_LocateRegistry$class_object;

#endif	/* _JC_java_rmi_registry_LocateRegistry_H_ */

==> jc-1.4.6.tar.gz: java/rmi/registry/LocateRegistry.h <==
// public final class java.rmi.registry.LocateRegistry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 93cb7af69e6ba275 java_rmi_registry_LocateRegistry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_registry_LocateRegistry_H_
#define _JC_java_rmi_registry_LocateRegistry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_registry_Registry$object;
struct _jc_java_rmi_server_RMIClientSocketFactory$object;
struct _jc_java_rmi_server_RMIServerSocketFactory$object;

// Typedefs
typedef struct _jc_java_rmi_registry_LocateRegistry$sub_refs	_jc_java_rmi_registry_LocateRegistry$sub_refs;
typedef struct _jc_java_rmi_registry_LocateRegistry$sub_nonrefs	_jc_java_rmi_registry_LocateRegistry$sub_nonrefs;
typedef struct _jc_java_rmi_registry_LocateRegistry$refs	_jc_java_rmi_registry_LocateRegistry$refs;
typedef struct _jc_java_rmi_registry_LocateRegistry$nonrefs	_jc_java_rmi_registry_LocateRegistry$nonrefs;
typedef struct _jc_java_rmi_registry_LocateRegistry$object	_jc_java_rmi_registry_LocateRegistry$object;

typedef const struct _jc_java_rmi_registry_LocateRegistry$vmethods	_jc_java_rmi_registry_LocateRegistry$vmethods;
typedef const struct _jc_java_rmi_registry_LocateRegistry$vtable	_jc_java_rmi_registry_LocateRegistry$vtable;
typedef const struct _jc_java_rmi_registry_LocateRegistry$vtype	_jc_java_rmi_registry_LocateRegistry$vtype;

// Constructors
extern void _jc_java_rmi_registry_LocateRegistry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_registry_LocateRegistry$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$createRegistry$3504ad846b08bdcc(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$createRegistry$bde0ac03af6cf041(_jc_env *, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$4a5a02146fc309d6(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$bc7b68f475c68629(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$a7faf9586294501a(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$5c01493dac7358a7(_jc_env *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_registry_LocateRegistry$method$getRegistry$99a1e5a9f3dd3803(_jc_env *, struct _jc_java_lang_String$object *, jint, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_registry_LocateRegistry$vmethods {
};

// Vtable
struct _jc_java_rmi_registry_LocateRegistry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_registry_LocateRegistry$vmethods	java_rmi_registry_LocateRegistry;
};

// Vtype
struct _jc_java_rmi_registry_LocateRegistry$vtype {
	_jc_type			type;
	_jc_java_rmi_registry_LocateRegistry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_registry_LocateRegistry$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_registry_LocateRegistry$refs {
    _jc_java_rmi_registry_LocateRegistry$sub_refs	java_rmi_registry_LocateRegistry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_registry_LocateRegistry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_registry_LocateRegistry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_registry_LocateRegistry$sub_nonrefs	java_rmi_registry_LocateRegistry;
};

// Object instance structure
struct _jc_java_rmi_registry_LocateRegistry$object {
	_jc_java_rmi_registry_LocateRegistry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_registry_LocateRegistry$vtype	*vtype;
	_jc_java_rmi_registry_LocateRegistry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_registry_LocateRegistry$vtype _jc_java_rmi_registry_LocateRegistry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_registry_LocateRegistry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_registry_LocateRegistry$class_object;

#endif	/* _JC_java_rmi_registry_LocateRegistry_H_ */
